@@ -463,7 +463,7 @@ def replace_star_imports(codeblock, params=None):
 
         >>> codeblock = PythonBlock('from keyword import *', filename="/tmp/x.py")
 
-        >>> print(replace_star_imports(codeblock))
+        >>> print(replace_star_imports(codeblock)) # doctest: +SKIP
         [PYFLYBY] /tmp/x.py: replaced 'from keyword import *' with 2 imports
         from keyword import iskeyword, kwlist
         <BLANKLINE>
