@@ -6,7 +6,6 @@ from __future__ import (absolute_import, division, print_function,
                         with_statement)
 
 import ast
-from collections import Sequence
 import contextlib
 import copy
 import six
@@ -15,6 +14,13 @@ from   six.moves                import builtins
 import sys
 import types
 
+if PY3:
+    from collections.abc import Sequence
+else:
+    # This is deprecated in Python 3
+    from collections import Sequence
+
+
 from   pyflyby._file            import FileText, Filename
 from   pyflyby._flags           import CompilerFlags
 from   pyflyby._idents          import (BadDottedIdentifierError,
@@ -420,6 +426,11 @@ class _MissingImportFinder(object):
                 self.visit(item)
         elif isinstance(node, ast.AST):
             method = 'visit_' + node.__class__.__name__
+            if not hasattr(self, method):
+                logger.debug(
+                    "_MissingImportFinder has no method %r, using generic_visit", method
+                )
+
             visitor = getattr(self, method, self.generic_visit)
             return visitor(node)
         else:
@@ -505,7 +516,21 @@ class _MissingImportFinder(object):
         # therefore think that the 'import foo' on L1 could be removed.
         self.visit(node.value)
         self.visit(node.targets)
+        self._visit__all__(node)
 
+    def _visit__all__(self, node):
+        if self._in_FunctionDef:
+            return
+        if (len(node.targets) == 1 and isinstance(node.targets[0], ast.Name)
+            and node.targets[0].id == '__all__'):
+            if not isinstance(node.value, ast.List):
+                logger.warning("Don't know how to handle __all__ as (%s)" % node.value)
+                return
+            if not all(isinstance(e, ast.Str) for e in node.value.elts):
+                logger.warning("Don't know how to handle __all__ with list elements other than str")
+                return
+            for e in node.value.elts:
+                self._visit_Load(e.s)
 
     def visit_ClassDef(self, node):
         if PY3:
@@ -522,6 +547,9 @@ class _MissingImportFinder(object):
         # class).
         self._visit_Store(node.name)
 
+    def visit_AsyncFunctionDef(self, node):
+        return self.visit_FunctionDef(node)
+
     def visit_FunctionDef(self, node):
         # Visit a function definition.
         #   - Visit args and decorator list normally.
@@ -840,8 +868,10 @@ class _MissingImportFinder(object):
             # On the other hand, we intentionally alias the other scopes
             # rather than cloning them, because the point is to allow them to
             # be modified until we do the check at the end.
-            data = (fullname, self.scopestack.clone_top(), self._lineno)
-            self._deferred_load_checks.append(data)
+
+            if symbol_needs_import(fullname, self.scopestack):
+                data = (fullname, self.scopestack.clone_top(), self._lineno)
+                self._deferred_load_checks.append(data)
         else:
             # We're not in a FunctionDef.  Deferring would give us the same
             # result; we do the check now to avoid the overhead of cloning the
