@@ -1351,19 +1351,23 @@ def test_parsable_missing_flags_auto_flags_1():
     block = PythonBlock("print(3, file=4)", auto_flags=True)
     assert block.parsable
 
-@pytest.mark.skipif(sys.version_info < (3,7), reason='invalid early python syntax')
-@pytest.mark.parametrize('input', [
-    "print(abc=123, *args, **kwargs)",
-    "print(*args, ijk=123, **kwargs)",
-    "print(7, *args, **kwargs)",
-    "print(*args, 12, **kwargs)",
-    ])
+
+@pytest.mark.skipif(PY2, reason="invalid early python syntax")
+@pytest.mark.parametrize(
+    "input",
+    [
+        "print(abc=123, *args, **kwargs)",
+        "print(*args, ijk=123, **kwargs)",
+        "print(7, *args, **kwargs)",
+        "print(*args, 12, **kwargs)",
+    ],
+)
 def test_parsable_Call_Ast_args_kwargs(input):
     block = PythonBlock(input, auto_flags=True)
     assert block.annotated_ast_node
 
 
-@pytest.mark.skipif(sys.version_info < (3, 6), reason="invalid early python syntax")
+@pytest.mark.skipif(PY2, reason="invalid early python syntax")
 @pytest.mark.parametrize(
     "input",
     [
@@ -1378,7 +1382,44 @@ def test_parsable_annotation_order(input):
     assert block.annotated_ast_node
 
 
-@pytest.mark.skipif(sys.version_info < (3, 6), reason="invalid early python syntax")
+@pytest.mark.skipif(PY2, reason="invalid early python syntax")
+@pytest.mark.parametrize(
+    "input",
+    [
+        '''x='abc'
+f"""\
+This is a
+multi-line
+f-string
+with input {x}.\
+"""
+''',
+        '''x=123
+f"""\
+{x}
+is the value x
+"""
+''',
+        '''x=456
+f"""{x}
+is the value x
+"""
+''',
+        '''x=123
+f"""\
+In the middle
+{x}
+is the value.
+"""
+''',
+    ],
+)
+def test_parse_f_string_ast_ann(input):
+    block = PythonBlock(input, auto_flags=True)
+    assert block.annotated_ast_node
+
+
+@pytest.mark.skipif(PY2, reason="invalid early python syntax")
 @pytest.mark.parametrize(
     "input",
     [
@@ -1386,9 +1427,46 @@ def test_parsable_annotation_order(input):
 x = 123
 fail_here = f"{x.stem} is no-op. \\
 (Do we need to delete this still?)"
-"""
+""",'''
+BLAH = "blah"
+
+def f(t):
+    pass
+
+f(f"""
+{BLAH}
+""")
+''',
+'''
+def foo():
+    return f"""
+        {name}
+    """
+'''
     ],
 )
 def test_join_formatted_string_columns(input):
     block = PythonBlock(input, auto_flags=True)
     assert block.annotated_ast_node
+
+
+@pytest.mark.parametrize(
+    "input",
+    [
+        '''b"""
+two
+""" b"""
+four
+five
+six
+"""
+''',
+        '''
+print(b"""
+""", sep="")
+''',
+    ],
+)
+def test_bytes_concat(input):
+    block = PythonBlock(input, auto_flags=True)
+    assert block.annotated_ast_node
